@@ -6,6 +6,7 @@ from sinto import (
     tagtorg,
     addbarcodes,
     tagtotag,
+    tagtoname
 )
 
 
@@ -20,6 +21,8 @@ def run_filterbarcodes(options):
         nproc=options.nproc,
         readname_barcode=options.barcode_regex,
         cellbarcode=options.barcodetag,
+        outdir=options.outdir,
+        sam=options.sam
     )
 
 
@@ -92,3 +95,24 @@ def run_barcode(options):
         prefix=options.prefix,
         suffix=options.suffix,
     )
+
+@utils.log_info
+def run_tagtoname(options):
+    tagtoname.move(
+        bam=options.bam,
+        output=options.output,
+        cb_tag=options.tag,
+        out_format=options.outputformat,
+        from_tag=True
+    )
+
+@utils.log_info
+def run_nametotag(options):
+    tagtoname.move(
+        bam=options.bam,
+        output=options.output,
+        cb_tag=options.tag,
+        out_format=options.outputformat,
+        from_tag=False,
+        cb_regex=options.barcode_regex
+    )
