@@ -4,6 +4,8 @@ import gzip
 import os
 import pysam
 import re
+import sys
+import math
 
 
 def log_info(func):
@@ -13,15 +15,17 @@ def log_info(func):
     @functools.wraps(func)
     def wrapper(args):
         print(
-            "Function {} called with the following arguments:\n".format(func.__name__)
+            "Function {} called with the following arguments:\n".format(func.__name__),
+            file=sys.stderr
         )
         for arg in vars(args):
-            print(str(arg) + "\t" + str(getattr(args, arg)))
+            print(str(arg) + "\t" + str(getattr(args, arg)), file=sys.stderr)
         t1 = time.time()
         func(args)
         t2 = time.time()
         elapsed = [round(x, 2) for x in divmod(t2 - t1, 60)]
-        print("\nFunction completed in  {} m {} s\n".format(elapsed[0], elapsed[1]))
+        print("\nFunction completed in  {} m {} s\n".format(elapsed[0], elapsed[1]),
+             file=sys.stderr)
 
     return wrapper
 
@@ -31,7 +35,7 @@ def chunk_bam(bamfile, nproc):
     chunk file into n chunks for multicore
     """
     chrom_lengths = bamfile.lengths
-    chunksize = sum(chrom_lengths) / int(nproc)
+    chunksize = int(sum(chrom_lengths) / int(nproc))
     intervals = []
     for x in range(1, nproc + 1):
         position = chunksize * x
